@@ -1,29 +1,40 @@
-use std::path::PathBuf;
+use std::{
+    io::{IsTerminal, stdout},
+    path::PathBuf,
+};
 
-use anyhow::{bail, Context, Result};
 use clap::{CommandFactory, Parser};
 use clap_complete::{generate, generate_to, shells};
-use log::warn;
-use simplelog::{Config, ConfigBuilder, LevelFilter, SimpleLogger};
-
-use pueue_lib::settings::Settings;
-
-use pueue::client::cli::{CliArguments, Shell, SubCommand};
-use pueue::client::client::Client;
+use color_eyre::{
+    Result,
+    eyre::{WrapErr, bail},
+};
+use pueue::client::{
+    cli::{CliArguments, ColorChoice, Shell, SubCommand},
+    handle_command,
+    style::OutputStyle,
+};
+use pueue_lib::{client::Client, settings::Settings};
 
 /// This is the main entry point of the client.
 ///
-/// At first we do some basic setup:
+/// The following happens in here:
 /// - Parse the cli
 /// - Initialize logging
 /// - Read the config
-///
-/// Once all this is done, we init the [Client] struct and start the main loop via [Client::start].
+/// - Default to `status` subcommand if no subcommand was specified
+/// - Determine the current
+/// - Initialize the [`Client`]
+/// - Handle the command
 #[tokio::main(flavor = "current_thread")]
 async fn main() -> Result<()> {
     // Parse commandline options.
     let opt = CliArguments::parse();
 
+    // Init the logger and set the verbosity level depending on the `-v` flags.
+    pueue::tracing::install_tracing(opt.verbose)?;
+    color_eyre::install()?;
+
     // In case the user requested the generation of shell completion file, create it and exit.
     if let Some(SubCommand::Completions {
         shell,
@@ -33,29 +44,9 @@ async fn main() -> Result<()> {
         return create_shell_completion_file(shell, output_directory);
     }
 
-    // Init the logger and set the verbosity level depending on the `-v` flags.
-    let level = match opt.verbose {
-        0 => LevelFilter::Error,
-        1 => LevelFilter::Warn,
-        2 => LevelFilter::Info,
-        _ => LevelFilter::Debug,
-    };
-
-    // Try to initialize the logger with the timezone set to the Local time of the machine.
-    let mut builder = ConfigBuilder::new();
-    let logger_config = match builder.set_time_offset_to_local() {
-        Err(_) => {
-            warn!("Failed to determine the local time of this machine. Fallback to UTC.");
-            Config::default()
-        }
-        Ok(builder) => builder.build(),
-    };
-
-    SimpleLogger::init(level, logger_config).unwrap();
-
     // Try to read settings from the configuration file.
     let (mut settings, config_found) =
-        Settings::read(&opt.config).context("Failed to read configuration.")?;
+        Settings::read(&opt.config).wrap_err("Failed to read configuration.")?;
 
     // Load any requested profile.
     if let Some(profile) = &opt.profile {
@@ -68,27 +59,37 @@ async fn main() -> Result<()> {
         bail!("Couldn't find a configuration file. Did you start the daemon yet?");
     }
 
-    // Warn if the deprecated --children option was used
-    if let Some(subcommand) = &opt.cmd {
-        if matches!(
-            subcommand,
-            SubCommand::Start { children: true, .. }
-                | SubCommand::Pause { children: true, .. }
-                | SubCommand::Kill { children: true, .. }
-                | SubCommand::Reset { children: true, .. }
-        ) {
-            println!(concat!(
-                "Note: The --children flag is deprecated and will be removed in a future release. ",
-                "It no longer has any effect, as this command now always applies to all processes in a task."
-            ));
-        }
-    }
+    // Determine the subcommand that has been called by the user.
+    // If no subcommand is given, we default to the `status` subcommand without any arguments.
+    let subcommand = opt.cmd.unwrap_or(SubCommand::Status {
+        json: false,
+        group: None,
+        query: Vec::new(),
+    });
+
+    // Determine whether we should color/style our output or not.
+    // The user can explicitly disable/enable this, otherwise we check whether we are on a TTY.
+    let style_enabled = match opt.color {
+        ColorChoice::Auto => stdout().is_terminal(),
+        ColorChoice::Always => true,
+        ColorChoice::Never => false,
+    };
+    let style = OutputStyle::new(&settings, style_enabled);
+
+    // Only show version incompatibility warnings if we aren't supposed to output json.
+    let show_version_warning = match subcommand {
+        SubCommand::Status { json, .. } => !json,
+        SubCommand::Log { json, .. } => !json,
+        SubCommand::Group { json, .. } => !json,
+        _ => true,
+    };
 
     // Create client to talk with the daemon and connect.
-    let mut client = Client::new(settings, opt)
+    let mut client = Client::new(settings, show_version_warning)
         .await
         .context("Failed to initialize client.")?;
-    client.start().await?;
+
+    handle_command(&mut client, &style, subcommand).await?;
 
     Ok(())
 }
