@@ -1,13 +1,9 @@
-use pueue_lib::log::clean_log_handles;
-use pueue_lib::network::message::*;
-use pueue_lib::state::SharedState;
-use pueue_lib::task::{TaskResult, TaskStatus};
+use pueue_lib::{TaskResult, TaskStatus, log::clean_log_handles, network::message::*};
 
 use super::*;
-use crate::daemon::state_helper::{is_task_removable, save_state};
-use crate::ok_or_return_failure_message;
+use crate::{daemon::internal_state::SharedState, ok_or_save_state_failure};
 
-fn construct_success_clean_message(message: CleanMessage) -> String {
+fn construct_success_clean_message(message: CleanRequest) -> String {
     let successful_only_fix = if message.successful_only {
         " successfully"
     } else {
@@ -24,23 +20,29 @@ fn construct_success_clean_message(message: CleanMessage) -> String {
 
 /// Invoked when calling `pueue clean`.
 /// Remove all failed or done tasks from the state.
-pub fn clean(message: CleanMessage, state: &SharedState, settings: &Settings) -> Message {
+pub fn clean(settings: &Settings, state: &SharedState, message: CleanRequest) -> Response {
     let mut state = state.lock().unwrap();
 
     let filtered_tasks =
-        state.filter_tasks(|task| matches!(task.status, TaskStatus::Done(_)), None);
+        state.filter_tasks(|task| matches!(task.status, TaskStatus::Done { .. }), None);
 
     for task_id in &filtered_tasks.matching_ids {
         // Ensure the task is removable, i.e. there are no dependant tasks.
-        if !is_task_removable(&state, task_id, &[]) {
+        if !state.is_task_removable(task_id, &[]) {
             continue;
         }
 
         if message.successful_only || message.group.is_some() {
-            if let Some(task) = state.tasks.get(task_id) {
+            if let Some(task) = state.tasks().get(task_id) {
                 // Check if we should ignore this task, if only successful tasks should be removed.
                 if message.successful_only
-                    && !matches!(task.status, TaskStatus::Done(TaskResult::Success))
+                    && !matches!(
+                        task.status,
+                        TaskStatus::Done {
+                            result: TaskResult::Success,
+                            ..
+                        }
+                    )
                 {
                     continue;
                 }
@@ -52,25 +54,25 @@ pub fn clean(message: CleanMessage, state: &SharedState, settings: &Settings) ->
                 }
             }
         }
-        let _ = state.tasks.remove(task_id).unwrap();
+        let _ = state.tasks_mut().remove(task_id).unwrap();
         clean_log_handles(*task_id, &settings.shared.pueue_directory());
     }
 
-    ok_or_return_failure_message!(save_state(&state, settings));
+    ok_or_save_state_failure!(state.save(settings));
 
-    create_success_message(construct_success_clean_message(message))
+    create_success_response(construct_success_clean_message(message))
 }
 
 #[cfg(test)]
 mod tests {
-    use super::super::fixtures::*;
-    use super::*;
-
     use pretty_assertions::assert_eq;
     use tempfile::TempDir;
 
-    fn get_message(successful_only: bool, group: Option<String>) -> CleanMessage {
-        CleanMessage {
+    use super::{super::fixtures::*, *};
+    use crate::daemon::internal_state::state::InternalState;
+
+    fn get_message(successful_only: bool, group: Option<String>) -> CleanRequest {
+        CleanRequest {
             successful_only,
             group,
         }
@@ -80,9 +82,9 @@ mod tests {
         fn add_stub_task(&mut self, id: &str, group: &str, task_result: TaskResult);
     }
 
-    impl TaskAddable for State {
+    impl TaskAddable for InternalState {
         fn add_stub_task(&mut self, id: &str, group: &str, task_result: TaskResult) {
-            let task = get_stub_task_in_group(id, group, TaskStatus::Done(task_result));
+            let task = get_stub_task_in_group(id, group, StubStatus::Done(task_result));
             self.add_task(task);
         }
     }
@@ -95,7 +97,7 @@ mod tests {
             let mut state = state.lock().unwrap();
 
             for &group in groups {
-                if !state.groups.contains_key(group) {
+                if !state.groups().contains_key(group) {
                     state.create_group(group);
                 }
 
@@ -116,16 +118,16 @@ mod tests {
         let (state, settings, _tempdir) = get_stub_state();
 
         // Only task 1 will be removed, since it's the only TaskStatus with `Done`.
-        let message = clean(get_message(false, None), &state, &settings);
+        let message = clean(&settings, &state, get_message(false, None));
 
         // Return message is correct
-        assert!(matches!(message, Message::Success(_)));
-        if let Message::Success(text) = message {
+        assert!(matches!(message, Response::Success(_)));
+        if let Response::Success(text) = message {
             assert_eq!(text, "All finished tasks have been removed");
         };
 
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.len(), 4);
+        assert_eq!(state.tasks().len(), 4);
     }
 
     #[test]
@@ -133,16 +135,16 @@ mod tests {
         let (state, settings, _tempdir) = get_clean_test_state(&[PUEUE_DEFAULT_GROUP]);
 
         // All finished tasks should removed when calling default `clean`.
-        let message = clean(get_message(false, None), &state, &settings);
+        let message = clean(&settings, &state, get_message(false, None));
 
         // Return message is correct
-        assert!(matches!(message, Message::Success(_)));
-        if let Message::Success(text) = message {
+        assert!(matches!(message, Response::Success(_)));
+        if let Response::Success(text) = message {
             assert_eq!(text, "All finished tasks have been removed");
         };
 
         let state = state.lock().unwrap();
-        assert!(state.tasks.is_empty());
+        assert!(state.tasks().is_empty());
     }
 
     #[test]
@@ -151,18 +153,18 @@ mod tests {
 
         // Only successfully finished tasks should get removed when
         // calling `clean` with the `successful_only` flag.
-        let message = clean(get_message(true, None), &state, &settings);
+        let message = clean(&settings, &state, get_message(true, None));
 
         // Return message is correct
-        assert!(matches!(message, Message::Success(_)));
-        if let Message::Success(text) = message {
+        assert!(matches!(message, Response::Success(_)));
+        if let Response::Success(text) = message {
             assert_eq!(text, "All successfully finished tasks have been removed");
         };
 
         // Assert that only the first entry has been deleted (TaskResult::Success)
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.len(), 5);
-        assert!(!state.tasks.contains_key(&0));
+        assert_eq!(state.tasks().len(), 5);
+        assert!(!state.tasks().contains_key(&0));
     }
 
     #[test]
@@ -170,12 +172,12 @@ mod tests {
         let (state, settings, _tempdir) = get_clean_test_state(&[PUEUE_DEFAULT_GROUP, "other"]);
 
         // All finished tasks should removed in selected group (other)
-        let message = clean(get_message(false, Some("other".into())), &state, &settings);
+        let message = clean(&settings, &state, get_message(false, Some("other".into())));
 
         // Return message is correct
-        assert!(matches!(message, Message::Success(_)));
+        assert!(matches!(message, Response::Success(_)));
 
-        if let Message::Success(text) = message {
+        if let Response::Success(text) = message {
             assert_eq!(
                 text,
                 "All finished tasks have been removed from group 'other'"
@@ -184,8 +186,8 @@ mod tests {
 
         // Assert that only the 'other' group has been cleared
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.len(), 6);
-        assert!(state.tasks.iter().all(|(_, task)| &task.group != "other"));
+        assert_eq!(state.tasks().len(), 6);
+        assert!(state.tasks().iter().all(|(_, task)| &task.group != "other"));
     }
 
     #[test]
@@ -193,21 +195,22 @@ mod tests {
         let (state, settings, _tempdir) = get_clean_test_state(&[PUEUE_DEFAULT_GROUP, "other"]);
 
         // Only successfully finished tasks should removed in the 'other' group
-        let message = clean(get_message(true, Some("other".into())), &state, &settings);
+        let message = clean(&settings, &state, get_message(true, Some("other".into())));
 
         // Return message is correct
-        assert!(matches!(message, Message::Success(_)));
+        assert!(matches!(message, Response::Success(_)));
 
-        if let Message::Success(text) = message {
+        if let Response::Success(text) = message {
             assert_eq!(
                 text,
                 "All successfully finished tasks have been removed from group 'other'"
             );
         };
 
-        // Assert that only the first entry has been deleted from the 'other' group (TaskResult::Success)
+        // Assert that only the first entry has been deleted from the 'other' group
+        // (TaskResult::Success)
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.len(), 11);
-        assert!(!state.tasks.contains_key(&6));
+        assert_eq!(state.tasks().len(), 11);
+        assert!(!state.tasks().contains_key(&6));
     }
 }
