@@ -1,20 +1,19 @@
-use pueue_lib::network::message::*;
-use pueue_lib::state::SharedState;
+use pueue_lib::{network::message::*, success_msg};
 
-use crate::daemon::network::response_helper::*;
+use crate::daemon::{internal_state::SharedState, network::response_helper::*};
 
 /// Set the parallel tasks for a specific group.
-pub fn set_parallel_tasks(message: ParallelMessage, state: &SharedState) -> Message {
+pub fn set_parallel_tasks(message: ParallelRequest, state: &SharedState) -> Response {
     let mut state = state.lock().unwrap();
     let group = match ensure_group_exists(&mut state, &message.group) {
         Ok(group) => group,
-        Err(message) => return message,
+        Err(response) => return response,
     };
 
     group.parallel_tasks = message.parallel_tasks;
 
-    create_success_message(format!(
+    success_msg!(
         "Parallel tasks setting for group \"{}\" adjusted",
         &message.group
-    ))
+    )
 }
