@@ -1,33 +1,34 @@
-use pueue_lib::network::message::*;
-use pueue_lib::settings::Settings;
-use pueue_lib::state::SharedState;
-use pueue_lib::task::TaskStatus;
+use pueue_lib::{Settings, TaskStatus, failure_msg, network::message::*};
 
 use super::ok_or_failure_message;
-use crate::daemon::state_helper::save_state;
-use crate::ok_or_return_failure_message;
+use crate::{daemon::internal_state::SharedState, ok_or_save_state_failure};
 
 /// Invoked when calling `pueue switch`.
 /// Switch the position of two tasks in the upcoming queue.
 /// We have to ensure that those tasks are either `Queued` or `Stashed`
-pub fn switch(message: SwitchMessage, state: &SharedState, settings: &Settings) -> Message {
+pub fn switch(settings: &Settings, state: &SharedState, message: SwitchRequest) -> Response {
     let mut state = state.lock().unwrap();
 
     let task_ids = [message.task_id_1, message.task_id_2];
     let filtered_tasks = state.filter_tasks(
-        |task| matches!(task.status, TaskStatus::Queued | TaskStatus::Stashed { .. }),
+        |task| {
+            matches!(
+                task.status,
+                TaskStatus::Queued { .. } | TaskStatus::Stashed { .. }
+            )
+        },
         Some(task_ids.to_vec()),
     );
     if !filtered_tasks.non_matching_ids.is_empty() {
-        return create_failure_message("Tasks have to be either queued or stashed.");
+        return failure_msg!("Tasks have to be either queued or stashed.");
     }
     if task_ids[0] == task_ids[1] {
-        return create_failure_message("You cannot switch a task with itself.");
+        return failure_msg!("You cannot switch a task with itself.");
     }
 
     // Get the tasks. Expect them to be there, since we found no mismatch
-    let mut first_task = state.tasks.remove(&task_ids[0]).unwrap();
-    let mut second_task = state.tasks.remove(&task_ids[1]).unwrap();
+    let mut first_task = state.tasks_mut().remove(&task_ids[0]).unwrap();
+    let mut second_task = state.tasks_mut().remove(&task_ids[1]).unwrap();
 
     // Switch task ids
     let first_id = first_task.id;
@@ -36,10 +37,10 @@ pub fn switch(message: SwitchMessage, state: &SharedState, settings: &Settings)
     second_task.id = first_id;
 
     // Put tasks back in again
-    state.tasks.insert(first_task.id, first_task);
-    state.tasks.insert(second_task.id, second_task);
+    state.tasks_mut().insert(first_task.id, first_task);
+    state.tasks_mut().insert(second_task.id, second_task);
 
-    for (_, task) in state.tasks.iter_mut() {
+    for (_, task) in state.tasks_mut().iter_mut() {
         // If the task depends on both, we can just keep it as it is.
         if task.dependencies.contains(&first_id) && task.dependencies.contains(&second_id) {
             continue;
@@ -55,8 +56,8 @@ pub fn switch(message: SwitchMessage, state: &SharedState, settings: &Settings)
         }
     }
 
-    ok_or_return_failure_message!(save_state(&state, settings));
-    create_success_message("Tasks have been switched")
+    ok_or_save_state_failure!(state.save(settings));
+    create_success_response("Tasks have been switched")
 }
 
 #[cfg(test)]
@@ -64,11 +65,10 @@ mod tests {
     use pretty_assertions::assert_eq;
     use tempfile::TempDir;
 
-    use super::super::fixtures::*;
-    use super::*;
+    use super::{super::fixtures::*, *};
 
-    fn get_message(task_id_1: usize, task_id_2: usize) -> SwitchMessage {
-        SwitchMessage {
+    fn get_message(task_id_1: usize, task_id_2: usize) -> SwitchRequest {
+        SwitchRequest {
             task_id_1,
             task_id_2,
         }
@@ -79,27 +79,27 @@ mod tests {
 
         {
             let mut state = state.lock().unwrap();
-            let task = get_stub_task("0", TaskStatus::Queued);
+            let task = get_stub_task("0", StubStatus::Queued);
             state.add_task(task);
 
-            let task = get_stub_task("1", TaskStatus::Stashed { enqueue_at: None });
+            let task = get_stub_task("1", StubStatus::Stashed { enqueue_at: None });
             state.add_task(task);
 
-            let task = get_stub_task("2", TaskStatus::Queued);
+            let task = get_stub_task("2", StubStatus::Queued);
             state.add_task(task);
 
-            let task = get_stub_task("3", TaskStatus::Stashed { enqueue_at: None });
+            let task = get_stub_task("3", StubStatus::Stashed { enqueue_at: None });
             state.add_task(task);
 
-            let mut task = get_stub_task("4", TaskStatus::Queued);
+            let mut task = get_stub_task("4", StubStatus::Queued);
             task.dependencies = vec![0, 3];
             state.add_task(task);
 
-            let mut task = get_stub_task("5", TaskStatus::Stashed { enqueue_at: None });
+            let mut task = get_stub_task("5", StubStatus::Stashed { enqueue_at: None });
             task.dependencies = vec![1];
             state.add_task(task);
 
-            let mut task = get_stub_task("6", TaskStatus::Queued);
+            let mut task = get_stub_task("6", StubStatus::Queued);
             task.dependencies = vec![2, 3];
             state.add_task(task);
         }
@@ -112,17 +112,17 @@ mod tests {
     fn switch_normal() {
         let (state, settings, _tempdir) = get_test_state();
 
-        let message = switch(get_message(1, 2), &state, &settings);
+        let response = switch(&settings, &state, get_message(1, 2));
 
-        // Return message is correct
-        assert!(matches!(message, Message::Success(_)));
-        if let Message::Success(text) = message {
+        // Response is correct
+        assert!(matches!(response, Response::Success(_)));
+        if let Response::Success(text) = response {
             assert_eq!(text, "Tasks have been switched");
         };
 
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.get(&1).unwrap().command, "2");
-        assert_eq!(state.tasks.get(&2).unwrap().command, "1");
+        assert_eq!(state.tasks().get(&1).unwrap().command, "2");
+        assert_eq!(state.tasks().get(&2).unwrap().command, "1");
     }
 
     #[test]
@@ -130,11 +130,11 @@ mod tests {
     fn switch_task_with_itself() {
         let (state, settings, _tempdir) = get_test_state();
 
-        let message = switch(get_message(1, 1), &state, &settings);
+        let response = switch(&settings, &state, get_message(1, 1));
 
-        // Return message is correct
-        assert!(matches!(message, Message::Failure(_)));
-        if let Message::Failure(text) = message {
+        // Response is correct
+        assert!(matches!(response, Response::Failure(_)));
+        if let Response::Failure(text) = response {
             assert_eq!(text, "You cannot switch a task with itself.");
         };
     }
@@ -145,10 +145,10 @@ mod tests {
     fn switch_task_with_dependant() {
         let (state, settings, _tempdir) = get_test_state();
 
-        switch(get_message(0, 3), &state, &settings);
+        switch(&settings, &state, get_message(0, 3));
 
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.get(&4).unwrap().dependencies, vec![0, 3]);
+        assert_eq!(state.tasks().get(&4).unwrap().dependencies, vec![0, 3]);
     }
 
     #[test]
@@ -157,11 +157,11 @@ mod tests {
     fn switch_double_dependency() {
         let (state, settings, _tempdir) = get_test_state();
 
-        switch(get_message(1, 2), &state, &settings);
+        switch(&settings, &state, get_message(1, 2));
 
         let state = state.lock().unwrap();
-        assert_eq!(state.tasks.get(&5).unwrap().dependencies, vec![2]);
-        assert_eq!(state.tasks.get(&6).unwrap().dependencies, vec![1, 3]);
+        assert_eq!(state.tasks().get(&5).unwrap().dependencies, vec![2]);
+        assert_eq!(state.tasks().get(&6).unwrap().dependencies, vec![1, 3]);
     }
 
     #[test]
@@ -182,11 +182,11 @@ mod tests {
         ];
 
         for ids in combinations {
-            let message = switch(get_message(ids.0, ids.1), &state, &settings);
+            let response = switch(&settings, &state, get_message(ids.0, ids.1));
 
-            // Assert, that we get a Failure message with the correct text.
-            assert!(matches!(message, Message::Failure(_)));
-            if let Message::Failure(text) = message {
+            // Assert, that we get a failure with the correct text.
+            assert!(matches!(response, Response::Failure(_)));
+            if let Response::Failure(text) = response {
                 assert_eq!(text, "Tasks have to be either queued or stashed.");
             };
         }
