@@ -1,10 +1,8 @@
-use anyhow::Result;
-
+use assert_matches::assert_matches;
 use chrono::Local;
-use pueue_lib::network::message::TaskSelection;
-use pueue_lib::task::*;
+use pueue_lib::{network::message::TaskSelection, task::*};
 
-use crate::helper::*;
+use crate::{helper::*, internal_prelude::*};
 
 /// Test if adding a normal task works as intended.
 #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
@@ -18,7 +16,7 @@ async fn test_normal_add() -> Result<()> {
     assert_success(add_task(shared, "sleep 0.01").await?);
 
     // Wait until the task finished and get state
-    let task = wait_for_task_condition(shared, 0, |task| task.is_done()).await?;
+    let task = wait_for_task_condition(shared, 0, Task::is_done).await?;
 
     let post_addition_time = Local::now();
 
@@ -27,16 +25,14 @@ async fn test_normal_add() -> Result<()> {
         task.created_at > pre_addition_time && task.created_at < post_addition_time,
         "Make sure the created_at time is set correctly"
     );
-    assert!(
-        task.enqueued_at.unwrap() > pre_addition_time
-            && task.enqueued_at.unwrap() < post_addition_time,
-        "Make sure the enqueue_at time is set correctly"
-    );
 
-    // The task finished successfully
-    assert_eq!(
+    assert_matches!(
         get_task_status(shared, 0).await?,
-        TaskStatus::Done(TaskResult::Success)
+        TaskStatus::Done {
+            result: TaskResult::Success,
+            ..
+        },
+        "Task should finish successfully",
     );
 
     Ok(())
@@ -51,18 +47,10 @@ async fn test_stashed_add() -> Result<()> {
     // Tell the daemon to add a task in stashed state.
     let mut message = create_add_message(shared, "sleep 60");
     message.stashed = true;
-    assert_success(send_message(shared, message).await?);
+    assert_success(send_request(shared, message).await?);
 
     // Make sure the task is actually stashed.
-    let task = wait_for_task_condition(shared, 0, |task| {
-        matches!(task.status, TaskStatus::Stashed { .. })
-    })
-    .await?;
-
-    assert!(
-        task.enqueued_at.is_none(),
-        "An unqueued task shouldn't have enqueue_at set."
-    );
+    assert_task_condition(shared, 0, Task::is_stashed, "The task should be stashed.").await?;
 
     Ok(())
 }
@@ -80,7 +68,13 @@ async fn test_add_with_immediate_start() -> Result<()> {
     assert_success(add_and_start_task(shared, "sleep 60").await?);
 
     // Make sure the task is actually being started.
-    wait_for_task_condition(shared, 0, |task| task.is_running()).await?;
+    assert_task_condition(
+        shared,
+        0,
+        Task::is_running,
+        "Tasks should start immediately",
+    )
+    .await?;
 
     Ok(())
 }
