@@ -1,12 +1,8 @@
-use anyhow::Result;
 use pretty_assertions::assert_eq;
+use pueue_lib::{GroupStatus, network::message::*, task::*};
 use rstest::rstest;
 
-use pueue_lib::network::message::*;
-use pueue_lib::state::GroupStatus;
-use pueue_lib::task::*;
-
-use crate::helper::*;
+use crate::{helper::*, internal_prelude::*};
 
 /// Test if killing running tasks works as intended.
 ///
@@ -20,26 +16,26 @@ use crate::helper::*;
 /// This is security measure to prevent unwanted task execution in an emergency.
 #[rstest]
 #[case(
-    KillMessage {
+    KillRequest {
         tasks: TaskSelection::All,
         signal: None,
     }, true
 )]
 #[case(
-    KillMessage {
+    KillRequest {
         tasks: TaskSelection::Group(PUEUE_DEFAULT_GROUP.into()),
         signal: None,
     }, true
 )]
 #[case(
-    KillMessage {
+    KillRequest {
         tasks: TaskSelection::TaskIds(vec![0, 1, 2]),
         signal: None,
     }, false
 )]
 #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
 async fn test_kill_tasks_with_pause(
-    #[case] kill_message: KillMessage,
+    #[case] kill_message: KillRequest,
     #[case] group_should_pause: bool,
 ) -> Result<()> {
     let daemon = daemon().await?;
@@ -49,9 +45,15 @@ async fn test_kill_tasks_with_pause(
     for _ in 0..3 {
         assert_success(add_and_start_task(shared, "sleep 60").await?);
     }
-    // Wait until all tasks are running
+    // Wait until all tasks are running, they should be start `immediately`.
     for id in 0..3 {
-        wait_for_task_condition(shared, id, |task| task.is_running()).await?;
+        assert_task_condition(
+            shared,
+            id,
+            Task::is_running,
+            "Tasks should start immediately.",
+        )
+        .await?;
     }
 
     // Add another task that will be normally enqueued.
@@ -60,12 +62,18 @@ async fn test_kill_tasks_with_pause(
     }
 
     // Send the kill message
-    send_message(shared, kill_message).await?;
+    send_request(shared, kill_message).await?;
 
     // Make sure all tasks get killed
     for id in 0..3 {
         wait_for_task_condition(shared, id, |task| {
-            matches!(task.status, TaskStatus::Done(TaskResult::Killed))
+            matches!(
+                task.status,
+                TaskStatus::Done {
+                    result: TaskResult::Killed,
+                    ..
+                }
+            )
         })
         .await?;
     }
@@ -92,25 +100,25 @@ async fn test_kill_tasks_with_pause(
 /// - Via specific ids.
 #[rstest]
 #[case(
-    KillMessage {
+    KillRequest {
         tasks: TaskSelection::All,
         signal: None,
     }
 )]
 #[case(
-    KillMessage {
+    KillRequest {
         tasks: TaskSelection::Group(PUEUE_DEFAULT_GROUP.into()),
         signal: None,
     }
 )]
 #[case(
-    KillMessage {
+    KillRequest {
         tasks: TaskSelection::TaskIds(vec![0, 1, 2]),
         signal: None,
     }
 )]
 #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
-async fn test_kill_tasks_without_pause(#[case] kill_message: KillMessage) -> Result<()> {
+async fn test_kill_tasks_without_pause(#[case] kill_message: KillRequest) -> Result<()> {
     let daemon = daemon().await?;
     let shared = &daemon.settings.shared;
 
@@ -118,21 +126,33 @@ async fn test_kill_tasks_without_pause(#[case] kill_message: KillMessage) -> Res
     for _ in 0..3 {
         assert_success(add_and_start_task(shared, "sleep 60").await?);
     }
-    // Wait until all tasks are running
+    // Wait until all tasks are running, they should be start `immediately`.
     for id in 0..3 {
-        wait_for_task_condition(shared, id, |task| task.is_running()).await?;
+        assert_task_condition(
+            shared,
+            id,
+            Task::is_running,
+            "Tasks should start immediately",
+        )
+        .await?;
     }
 
     // Add a dummy group that also shouldn't be paused.
     add_group_with_slots(shared, "testgroup", 1).await?;
 
     // Send the kill message
-    send_message(shared, kill_message).await?;
+    send_request(shared, kill_message).await?;
 
     // Make sure all tasks get killed
     for id in 0..3 {
         wait_for_task_condition(shared, id, |task| {
-            matches!(task.status, TaskStatus::Done(TaskResult::Killed))
+            matches!(
+                task.status,
+                TaskStatus::Done {
+                    result: TaskResult::Killed,
+                    ..
+                }
+            )
         })
         .await?;
     }
