@@ -1,8 +1,6 @@
 use std::io::Read;
 
-use anyhow::{bail, Context, Result};
-use pueue_lib::network::message::*;
-use pueue_lib::settings::*;
+use pueue_lib::{network::message::*, settings::*};
 use snap::read::FrameDecoder;
 
 use super::*;
@@ -22,24 +20,24 @@ pub fn decompress_log(bytes: Vec<u8>) -> Result<String> {
 /// Convenience function to get the log of a specific task.
 /// `lines: None` requests all log lines.
 pub async fn get_task_log(shared: &Shared, task_id: usize, lines: Option<usize>) -> Result<String> {
-    let message = LogRequestMessage {
-        task_ids: vec![task_id],
+    let message = LogRequest {
+        tasks: TaskSelection::TaskIds(vec![task_id]),
         send_logs: true,
         lines,
     };
-    let response = send_message(shared, message).await?;
+    let response = send_request(shared, message).await?;
 
     let mut logs = match response {
-        Message::LogResponse(logs) => logs,
+        Response::Log(logs) => logs,
         _ => bail!("Didn't get log response response in get_state"),
     };
 
     let log = logs
         .remove(&task_id)
-        .context("Didn't find log of requested task")?;
+        .ok_or(eyre!("Didn't find log of requested task"))?;
     let bytes = log
         .output
-        .context("Didn't get log output even though requested.")?;
+        .ok_or(eyre!("Didn't get log output even though requested."))?;
 
     decompress_log(bytes)
 }
