@@ -1,16 +1,12 @@
-use anyhow::{bail, Result};
-
-use pueue_lib::network::message::*;
-use pueue_lib::settings::*;
-use pueue_lib::state::State;
+use pueue_lib::{network::message::*, settings::*, state::State};
 
 use super::*;
 
 /// Convenience function for getting the current state from the daemon.
 pub async fn get_state(shared: &Shared) -> Result<Box<State>> {
-    let response = send_message(shared, Message::Status).await?;
+    let response = send_request(shared, Request::Status).await?;
     match response {
-        Message::StatusResponse(state) => Ok(state),
+        Response::Status(state) => Ok(state),
         _ => bail!("Didn't get status response in get_state"),
     }
 }
