@@ -1,14 +1,14 @@
-use std::collections::HashMap;
-use std::fs::{create_dir_all, File};
-use std::io::{prelude::*, BufReader};
-use std::path::{Path, PathBuf};
+use std::{
+    collections::HashMap,
+    fs::{File, create_dir_all},
+    io::{BufReader, prelude::*},
+    path::{Path, PathBuf},
+};
 
-use log::info;
-use serde_derive::{Deserialize, Serialize};
+use serde::{Deserialize, Serialize};
 use shellexpand::tilde;
 
-use crate::error::Error;
-use crate::setting_defaults::*;
+use crate::{error::Error, internal_prelude::*, setting_defaults::*};
 
 /// The environment variable that can be set to overwrite pueue's config path.
 pub const PUEUE_CONFIG_PATH_ENV: &str = "PUEUE_CONFIG_PATH";
@@ -46,6 +46,12 @@ pub struct Shared {
     /// The path to the unix socket.
     #[cfg(not(target_os = "windows"))]
     pub unix_socket_path: Option<PathBuf>,
+    /// Unix socket permissions. Typically specified as an octal number and
+    /// defaults to `0o700` which grants only the current user access to the
+    /// socket. For a client to connect to the daemon, the client must have
+    /// read/write permissions.
+    #[cfg(not(target_os = "windows"))]
+    pub unix_socket_permissions: Option<u32>,
 
     /// The TCP hostname/ip address.
     #[serde(default = "default_host")]
@@ -76,6 +82,17 @@ pub struct Shared {
     pub shared_secret_path: Option<PathBuf>,
 }
 
+/// The mode in which the client should edit tasks.
+#[derive(PartialEq, Eq, Clone, Debug, Deserialize, Serialize, Default)]
+#[serde(rename_all = "lowercase")]
+pub enum EditMode {
+    /// Edit by having one large file with all tasks to be edited inside at the same time
+    #[default]
+    Toml,
+    /// Edit by creating a folder for each task to be edited, where each property is a single file.
+    Files,
+}
+
 /// All settings which are used by the client
 #[derive(PartialEq, Eq, Clone, Debug, Deserialize, Serialize)]
 pub struct Client {
@@ -91,6 +108,9 @@ pub struct Client {
     /// Whether the client should show a confirmation question on potential dangerous actions.
     #[serde(default = "Default::default")]
     pub show_confirmation_questions: bool,
+    /// Whether the client should show a confirmation question on potential dangerous actions.
+    #[serde(default = "Default::default")]
+    pub edit_mode: EditMode,
     /// Whether aliases specified in `pueue_aliases.yml` should be expanded in the `pueue status`
     /// or shown in their short form.
     #[serde(default = "Default::default")]
@@ -117,6 +137,14 @@ pub struct Daemon {
     /// Whether the daemon (and all groups) should be paused as soon as a single task fails
     #[serde(default = "Default::default")]
     pub pause_all_on_failure: bool,
+    /// If this is set to `true`, the status file will be compressed, which usually results in a
+    /// significantly smaller file. This is particularily useful for I/O starved or embedded
+    /// environments, as it trades a bit of CPU power for I/O ops.
+    ///
+    /// The state tends to be quite large for many tasks, as the whole environment is copied every
+    /// time. You can expect a ~10 compression ratio.
+    #[serde(default = "Default::default")]
+    pub compress_state_file: bool,
     /// The callback that's called whenever a task finishes.
     pub callback: Option<String>,
     /// Environment variables that can be will be injected into all executed processes.
@@ -129,10 +157,18 @@ pub struct Daemon {
     /// The following are the only officially supported modi for Pueue.
     ///
     /// Unix default:
-    /// `vec!["sh", "-c", "{{ pueue_command_string }}"]`.
+    /// ```
+    /// vec!["sh", "-c", "{{ pueue_command_string }}"];
+    /// ````
     ///
     /// Windows default:
-    /// `vec!["powershell", "-c", "[Console]::OutputEncoding = [Text.UTF8Encoding]::UTF8; {{ pueue_command_string }}"]`
+    /// ```
+    /// vec![
+    ///     "powershell",
+    ///     "-c",
+    ///     "[Console]::OutputEncoding = [Text.UTF8Encoding]::UTF8; {{ pueue_command_string }}",
+    /// ];
+    /// ```
     pub shell_command: Option<Vec<String>>,
 }
 
@@ -147,6 +183,8 @@ impl Default for Shared {
             unix_socket_path: None,
             #[cfg(not(target_os = "windows"))]
             use_unix_socket: true,
+            #[cfg(not(target_os = "windows"))]
+            unix_socket_permissions: Some(0o700),
             host: default_host(),
             port: default_port(),
 
@@ -165,6 +203,7 @@ impl Default for Client {
             read_local_logs: true,
             show_confirmation_questions: false,
             show_expanded_aliases: false,
+            edit_mode: Default::default(),
             dark_mode: false,
             max_status_lines: None,
             status_time_format: default_status_time_format(),
@@ -180,6 +219,7 @@ impl Default for Daemon {
             pause_all_on_failure: false,
             callback: None,
             callback_log_lines: default_callback_log_lines(),
+            compress_state_file: false,
             shell_command: None,
             env_vars: HashMap::new(),
         }
@@ -400,7 +440,7 @@ impl Settings {
             Err(error) => {
                 return Err(Error::Generic(format!(
                     "Configuration file serialization failed:\n{error}"
-                )))
+                )));
             }
         };
         let mut file = File::create(&config_path).map_err(|err| {
