@@ -1,8 +1,7 @@
 use std::path::PathBuf;
 
-use anyhow::{Context, Result};
-
-use pueue_lib::settings::Settings;
+use color_eyre::{Result, eyre::WrapErr};
+use pueue_lib::Settings;
 
 /// From 0.15.0 on, we aim to have full backward compatibility.
 /// For this reason, an old (slightly modified) v0.15.0 serialized settings file
@@ -15,7 +14,7 @@ use pueue_lib::settings::Settings;
 /// On top of simply having old settings, I also removed a few default fields.
 /// This should be handled as well.
 #[test]
-fn test_restore_from_old_state() -> Result<()> {
+fn test_restore_from_old_settings() -> Result<()> {
     better_panic::install();
     let old_settings_path = PathBuf::from(env!("CARGO_MANIFEST_DIR"))
         .join("tests")
@@ -24,7 +23,7 @@ fn test_restore_from_old_state() -> Result<()> {
 
     // Open v0.15.0 file and ensure the settings file can be read.
     let (_settings, config_found) = Settings::read(&Some(old_settings_path))
-        .context("Failed to read old config with defaults:")?;
+        .wrap_err("Failed to read old config with defaults:")?;
 
     assert!(config_found);
 
